@@ -31,16 +31,18 @@
 #include <config.h>
 #endif
 
+#include <string.h>
+
+#include <glib/gi18n.h>
+
 #include "gedit-encodings.h"
 
-#include <bonobo/bonobo-i18n.h>
-#include <string.h>
 
 struct _GeditEncoding
 {
-  gint   index;
-  gchar *charset;
-  gchar *name;
+	gint   index;
+	gchar *charset;
+	gchar *name;
 };
 
 /* 
@@ -132,6 +134,7 @@ static GeditEncoding utf8_encoding =
 	  N_("Unicode") 
 	};
 
+/* initialized in gedit_encoding_lazy_init() */
 static GeditEncoding unknown_encoding = 
 	{ GEDIT_ENCODING_UNKNOWN,
 	  NULL, 
@@ -314,12 +317,6 @@ gedit_encoding_get_from_charset (const gchar *charset)
 	if (g_ascii_strcasecmp (charset, "UTF-8") == 0)
 		return gedit_encoding_get_utf8 ();
 
-	if (unknown_encoding.charset != NULL)
-	{
-		if (g_ascii_strcasecmp (charset, unknown_encoding.charset) == 0)
-			return &unknown_encoding;
-	}
-
 	i = 0; 
 	while (i < GEDIT_ENCODING_LAST)
 	{
@@ -329,6 +326,12 @@ gedit_encoding_get_from_charset (const gchar *charset)
 		++i;
 	}
 
+	if (unknown_encoding.charset != NULL)
+	{
+		if (g_ascii_strcasecmp (charset, unknown_encoding.charset) == 0)
+			return &unknown_encoding;
+	}
+
 	return NULL;
 }
 
@@ -388,7 +391,6 @@ gedit_encoding_get_current (void)
 
 	return locale_encoding;
 }
-	
 
 gchar *
 gedit_encoding_to_string (const GeditEncoding* enc)
@@ -428,7 +430,6 @@ gedit_encoding_get_name (const GeditEncoding* enc)
 
 	gedit_encoding_lazy_init ();
 
-	return enc->name;
+	return (enc->name == NULL) ? _("Unknown") : enc->name;
 }
 
-
